@@ -19,11 +19,12 @@ use strict;
 use warnings;
 
 use base qw(EBox::GConfModule 
-			EBox::ObjectsObserver 
-			EBox::NetworkObserver
-			EBox::Model::ModelProvider
-			EBox::ServiceModule::ServiceInterface
-			);
+		EBox::ObjectsObserver 
+		EBox::NetworkObserver
+		EBox::LogObserver
+		EBox::Model::ModelProvider
+		EBox::ServiceModule::ServiceInterface
+		);
 
 use EBox::Objects;
 use EBox::Global;
@@ -44,42 +45,38 @@ sub _create
 {
 	my $class = shift;
 	my $self =$class->SUPER::_create(
-                                         name => 'firewall',
-                                         domain => 'ebox-firewall',
-                                         printableName => __('firewall'),
-					@_);
-    $self->{'ToInternetRuleModel'} = 
-            new EBox::Firewall::Model::ToInternetRuleTable(
-               'gconfmodule' => $self,
-                'directory' => 'ToInternetRuleTable',
-                );
-
-    $self->{'InternalToEBoxRuleModel'} = 
-            new EBox::Firewall::Model::InternalToEBoxRuleTable(
-               'gconfmodule' => $self,
-                'directory' => 'InternalToEBoxRuleTable',
-                );
-    
-    $self->{'ExternalToEBoxRuleModel'} = 
-            new EBox::Firewall::Model::ExternalToEBoxRuleTable(
-               'gconfmodule' => $self,
-                'directory' => 'ExternalToEBoxRuleTable',
-                );
-    
-    $self->{'EBoxOutputRuleModel'} = 
-            new EBox::Firewall::Model::EBoxOutputRuleTable(
-               'gconfmodule' => $self,
-                'directory' => 'EBoxOutputRuleTable',
-                );
-    $self->{'ExternalToInternalRuleTable'} = 
-            new EBox::Firewall::Model::ExternalToInternalRuleTable(
-               'gconfmodule' => $self,
-                'directory' => 'ExternalToInternalRuleTable',
-                );
-
+			name => 'firewall',
+			domain => 'ebox-firewall',
+			printableName => __('firewall'),
+			@_);
+	$self->{'ToInternetRuleModel'} = 
+		new EBox::Firewall::Model::ToInternetRuleTable(
+				'gconfmodule' => $self,
+				'directory' => 'ToInternetRuleTable',
+				);
 
+	$self->{'InternalToEBoxRuleModel'} = 
+		new EBox::Firewall::Model::InternalToEBoxRuleTable(
+				'gconfmodule' => $self,
+				'directory' => 'InternalToEBoxRuleTable',
+				);
 
+	$self->{'ExternalToEBoxRuleModel'} = 
+		new EBox::Firewall::Model::ExternalToEBoxRuleTable(
+				'gconfmodule' => $self,
+				'directory' => 'ExternalToEBoxRuleTable',
+				);
 
+	$self->{'EBoxOutputRuleModel'} = 
+		new EBox::Firewall::Model::EBoxOutputRuleTable(
+				'gconfmodule' => $self,
+				'directory' => 'EBoxOutputRuleTable',
+				);
+	$self->{'ExternalToInternalRuleTable'} = 
+		new EBox::Firewall::Model::ExternalToInternalRuleTable(
+				'gconfmodule' => $self,
+				'directory' => 'ExternalToInternalRuleTable',
+				);
 
 	bless($self, $class);
 	return $self;
@@ -94,17 +91,17 @@ sub actions
 	return [ 
 	{
 		'action' => __('Flush previous firewall rules'),
-		'reason' => __('The eBox firewall will flush any previous firewall rule ' .
-					' which have been added manually or by another tool'),
+		'reason' => __('The eBox firewall will flush any previous firewall '
+                               . 'rules which have been added manually or by another tool'),
 		'module' => 'firewall'
 	},
 	{
 		'action' => __('Secure by default'),
 		'reason' => __('Just a few connections are allowed by default. ' .
-					'Make sure you add the proper incoming and outcoming ' .
-					'rules to make your system work as expected. Usually, ' .
-					'all outcoming connections are denied by default, and ' .
-					'only SSH and HTTPS incoming connections are allowed.'),
+			       'Make sure you add the proper incoming and outcoming ' .
+			       'rules to make your system work as expected. Usually, ' .
+			       'all outcoming connections are denied by default, and ' .
+			       'only SSH and HTTPS incoming connections are allowed.'),
 		'module' => 'firewall'
 
 	}
@@ -134,13 +131,13 @@ sub enableModDepends
 #      Overrides <EBox::Model::ModelProvider::models>
 #
 sub models {
-       my ($self) = @_;
+	my ($self) = @_;
 
-       return [$self->{'ToInternetRuleModel'},
-      		 $self->{'InternalToEBoxRuleModel'},
-		 $self->{'ExternalToEBoxRuleModel'},
-		 $self->{'EBoxOutputRuleModel'},
-		 $self->{'ExternalToInternalRuleTable'}];
+	return [$self->{'ToInternetRuleModel'},
+		   $self->{'InternalToEBoxRuleModel'},
+		   $self->{'ExternalToEBoxRuleModel'},
+		   $self->{'EBoxOutputRuleModel'},
+		   $self->{'ExternalToInternalRuleTable'}];
 }
 
 # Method: _exposedMethods
@@ -152,20 +149,20 @@ sub models {
 sub _exposedMethods
 {
 
-    my %exposedMethods = (
-                          addOutputService => { action => 'add',
-                                                path   => [ 'EBoxOutputRuleTable' ] },
-                          removeOutputService => { action => 'del',
-                                                   path   => [ 'EBoxOutputRuleTable' ],
-                                                   indexes => [ 'id' ]
-                                                 },
-                          getOutputService => { action  => 'get',
-                                                path    => [ 'EBoxOutputRuleTable' ],
-                                                indexes => [ 'position' ],
-                                              },
-                          );
+	my %exposedMethods = (
+			addOutputService => { action => 'add',
+			path   => [ 'EBoxOutputRuleTable' ] },
+			removeOutputService => { action => 'del',
+			path   => [ 'EBoxOutputRuleTable' ],
+			indexes => [ 'id' ]
+			},
+			getOutputService => { action  => 'get',
+			path    => [ 'EBoxOutputRuleTable' ],
+			indexes => [ 'position' ],
+			},
+			);
 
-    return \%exposedMethods;
+	return \%exposedMethods;
 
 }
 
@@ -173,10 +170,10 @@ sub _exposedMethods
 
 sub externalIfaceExists
 {
-  my $network = EBox::Global->modInstance('network');
-  my $externalIfaceExists = @{$network->ExternalIfaces()  } > 0;
-  
-  return $externalIfaceExists;
+	my $network = EBox::Global->modInstance('network');
+	my $externalIfaceExists = @{$network->ExternalIfaces()  } > 0;
+
+	return $externalIfaceExists;
 }
 
 ## internal utility functions
@@ -389,14 +386,14 @@ sub availablePort # (proto, port, interface)
 	($port ne "") or return undef;
 	my $global = EBox::Global->getInstance();
 	my $network = $global->modInstance('network');
-    my $services = $global->modInstance('services');
+	my $services = $global->modInstance('services');
 
 	# if it's an internal interface, check all services
 	unless ($iface &&
-	($network->ifaceIsExternal($iface) || $network->vifaceExists($iface))) {
-        unless ($services->availablePort($proto, $port)) {
-            return undef;
-        }
+			($network->ifaceIsExternal($iface) || $network->vifaceExists($iface))) {
+		unless ($services->availablePort($proto, $port)) {
+			return undef;
+		}
 	}
 
 	# check for port redirections on the interface, on all internal ifaces
@@ -418,11 +415,11 @@ sub availablePort # (proto, port, interface)
 	}
 
 	my @mods = @{$global->modInstancesOfType('EBox::FirewallObserver')};
-        foreach my $mod (@mods) {
-                if ($mod->usesPort($proto, $port, $iface)) {
-                        return undef;
-                }
-        }
+	foreach my $mod (@mods) {
+		if ($mod->usesPort($proto, $port, $iface)) {
+			return undef;
+		}
+	}
 	return 1;
 }
 
@@ -671,7 +668,7 @@ sub addOutputRule # (protocol, port)
 
 # Method: setInternalService
 #
-# 	This method adds a rule to the "internal networks to eBox services"
+#   This method adds a rule to the "internal networks to eBox services"
 #   table.
 #
 #   In case the service has already been configured with a custom
@@ -699,6 +696,46 @@ sub setInternalService
 {
 	my ($self, $service, $decision) = @_;
 
+	return $self->_setService($service, $decision, 1);
+}
+
+# Method: setExternalService
+#
+#   This method adds a rule to the "external networks to eBox services"
+#   table.
+#
+#   In case the service has already been configured with a custom
+#   rule by the user the adding operation is aborted.
+#
+#   Modules configuring internal services running on eBox should use
+#   this method if they wish to allow access from external networks
+#   to the service by default.
+#
+# Parameters:
+#
+#   service - service's name
+#   decision - accept or deny
+# 	
+# Returns:
+#
+#   boolan - true if the rule has been added, otherwise false and
+#            that implies there is already a custom rule
+#
+# Exceptions:
+#
+#   <EBox::Exceptions::MissingArgument>
+#   <EBox::Exceptions::DataNotFound>
+sub setExternalService
+{
+	my ($self, $service, $decision) = @_;
+
+	return $self->_setService($service, $decision, 0);
+}
+
+sub _setService
+{
+	my ($self, $service, $decision, $internal) = @_;
+
 	my $serviceMod = EBox::Global->modInstance('services');
 
 	unless (defined($service)) {
@@ -721,7 +758,14 @@ sub setInternalService
 				'value' => $service);
 	}
 
-	my $rulesModel = $self->{'InternalToEBoxRuleModel'};
+
+	my $model;
+	if ($internal) {
+		$model = 'InternalToEBoxRuleModel';
+	} else {
+		$model = 'ExternalToEBoxRuleModel';
+	}
+	my $rulesModel = $self->{$model};
 
 	# Do not add rule if there is already a rule
 	if ($rulesModel->findValue('service' => $serviceId)) {
@@ -738,7 +782,6 @@ sub setInternalService
 
 	return 1;
 }
-
 # Method: enableLog 
 #
 #   Override <EBox::LogObserver>
@@ -764,11 +807,11 @@ sub enableLog
 #
 sub setLogging
 {
-    my ($self, $enable) = @_;
+	my ($self, $enable) = @_;
 
-    if ($enable xor $self->logging()) {
-        $self->set_bool('logging', $enable);
-    }
+	if ($enable xor $self->logging()) {
+		$self->set_bool('logging', $enable);
+	}
 }
 
 # Method: logging 
@@ -782,36 +825,9 @@ sub setLogging
 #
 sub logging
 {
-    my ($self) = @_;
-
-    return  $self->get_bool('logging');
-}
-
-
-
-# Method: onInstall
-#
-# 	Method to execute the first time the module is installed.
-#
-sub onInstall
-{
-	EBox::init();
-
-	my $fw = EBox::Global->instance()->modInstance('firewall');
-	$fw->setInternalService('eBox administration', 'accept');
-	$fw->setInternalService('ssh', 'accept');
-
-	$fw->saveConfigRecursive();
-}
-
-# Method: onRemove
-#
-# 	Method to execute before the module is uninstalled
-#
-sub onRemove
-{
-	EBox::init();
+	my ($self) = @_;
 
+	return  $self->get_bool('logging');
 }
 
 # Method: menu 
@@ -864,7 +880,7 @@ sub menu
 
 # Impelment LogHelper interface
 sub tableInfo {
-        my ($self) = @_ ;
+	my ($self) = @_ ;
 	
 	my $titles = { 
 			'timestamp' => __('Date'),
@@ -876,11 +892,11 @@ sub tableInfo {
 			'fw_spt'    => __('Source port'),
 			'fw_dpt'    => __('Destination port'),
 			'event'     => __('Decision')
-		      };
+	};
 	
-	my @order = qw(timestamp fw_in fw_out fw_src fw_dst fw_proto fw_spt fw_dpt);
+	my @order = qw(timestamp fw_in fw_out fw_src fw_dst fw_proto fw_spt fw_dpt event);
 	
-	my $events = { 'drop' => __('DROP') };
+	my $events = { 'drop' => __('DROP'), 'log' => __('LOG') };
 
 	return {
 		'name' => __('Firewall'),
@@ -899,9 +915,9 @@ sub tableInfo {
 
 sub logHelper
 {
-        my $self = shift;
+	my $self = shift;
 
-        return (new EBox::FirewallLogHelper);
+	return (new EBox::FirewallLogHelper);
 }
 
 
