@@ -172,6 +172,8 @@ sub setStructure
 
 	pf '-N drop';
 
+	pf '-N log';
+
 	pf '-N ointernal';
 	pf '-N omodules';
 	pf '-N oglobal';
@@ -226,6 +228,21 @@ sub setDNS # (dns)
 	pf "-A fdns $new -p udp --dport 53 -d $dns -j ACCEPT";
 }
 
+# Method: setDHCP
+#
+#       Set output DHCP traffic 
+#
+# Parameters:
+#
+#       interface - 
+#
+sub setDHCP 
+{
+	my $self = shift;
+	my $interface = shift;
+	pf "-A ointernal $new -o $interface -p udp --dport 67 -j ACCEPT";
+}
+
 # Method: nospoof
 #
 #       Set no IP spoofing (forged) for the given addresses to the
@@ -379,7 +396,7 @@ sub start
 	}
 
 	foreach my $object (@{$self->{objects}->objects}) {
-		my $members = $self->{objects}->objectMembers($object);
+		my $members = $self->{objects}->objectMembers($object->{id});
 		foreach my $member (@{$members}) {
 			my $mac = $member->{macaddr};
 			defined($mac) or next;
@@ -397,6 +414,7 @@ sub start
 		my $addrs = $self->{net}->ifaceAddresses($ifc);
 		$self->nospoof($ifc, $addrs);
 		if ($self->{net}->ifaceMethod($ifc) eq 'dhcp') {
+			$self->setDHCP($ifc);
 			my $dnsSrvs = $self->{net}->DHCPNameservers($ifc);
 			foreach my $srv (@{$dnsSrvs}) {
 				$self->setDNS($srv);
@@ -419,6 +437,8 @@ sub start
 		pf "-A inoexternal $new -i $if -j idrop";
 		pf "-A ftoexternalonly -o $if -j ACCEPT";
 
+		next unless (_natEnabled());
+
 		if ($self->{net}->ifaceMethod($if) eq 'static') {
 			my $addr = $self->{net}->ifaceAddress($if);
 			pf "-t nat -A POSTROUTING -s ! $addr -o $if " .
@@ -430,6 +450,8 @@ sub start
 
 	$self->_drop();
 
+	$self->_log();
+
 	$self->_iexternal();
 	$self->_iglobal();
 
@@ -498,13 +520,9 @@ sub _iexternalCheckInit
 
     my @internalIfaces = @{$self->{net}->InternalIfaces()};
     foreach my $if (@internalIfaces) {
-        pf "-A inointernal -i $if -j RETURN";
+        pf "-A iexternalmodules -i $if -j RETURN";
+        pf "-A iexternal -i $if -j RETURN";
     }
-
-    pf "-I iexternalmodules -j inointernal";
-    pf "-I iexternal -j inointernal";
-
-
 }
 
 # Method: _iexternal
@@ -579,6 +597,10 @@ sub _ffwdrules
 {
     my ($self) = @_;
 
+    my @internalIfaces = @{$self->{net}->InternalIfaces()};
+    foreach my $if (@internalIfaces) {
+        pf " -A ffwdrules -i $if -j RETURN";
+    }
     my $iptHelper = new EBox::Firewall::IptablesHelper;
     for my $rule (@{$iptHelper->ExternalToInternalRuleTable()}) {
         pf "$rule";
@@ -617,7 +639,56 @@ sub _drop
     }
     pf "-I drop -j LOG -m limit --limit $limit/min --limit-burst $burst" . 
        ' --log-level ' . SYSLOG_LEVEL . 
-       ' --log-prefix "ebox-firewall "';
+       ' --log-prefix "ebox-firewall drop "';
+}
+
+# Method: _log
+#
+#	Set up log chain. Log rule and return rule
+#	
+sub _log
+{
+    my ($self) = @_;
+
+    pf '-I log -j RETURN';
+
+    # If logging is disabled we are done
+    return unless ($self->{firewall}->logging());
+
+    my $limit = EBox::Config::configkey('iptables_log_limit');
+    my $burst = EBox::Config::configkey('iptables_log_burst');
+
+    unless (defined($limit) and $limit =~ /^\d+$/) {
+	throw EBox::Exceptions::External(__('You must set the ' .
+		'iptables_log_limit variable in the ebox configuration file'));
+
+    }
+
+    unless (defined($burst) and $burst =~ /^\d+$/) {
+	throw EBox::Exceptions::External(__('You must set the ' .
+		'iptables_log_burst variable in the ebox configuration file'));
+
+    }
+    pf "-I log -j LOG -m limit --limit $limit/min --limit-burst $burst" . 
+       ' --log-level ' . SYSLOG_LEVEL . 
+       ' --log-prefix "ebox-firewall log "';
+}
+
+# Method: _natEnabled
+#
+#   Fetch value to enable NAT
+#
+sub _natEnabled
+{
+	my $nat =  EBox::Config::configkey('nat_enabled');
+
+	return 1 unless (defined($nat));
+
+	if ($nat =~ /no/) {
+		return undef;
+	} else {
+		return 1;
+	}
 }
 
 1;
